@@ -47,7 +47,7 @@ QString PackageKitResource::packageName() const
 
 QStringList PackageKitResource::allPackageNames() const
 {
-    return QStringList(m_name);
+    return { m_name };
 }
 
 QString PackageKitResource::availablePackageId() const
@@ -65,7 +65,8 @@ QString PackageKitResource::availablePackageId() const
 
 QString PackageKitResource::installedPackageId() const
 {
-    return m_packages[PackageKit::Transaction::InfoInstalled].first();
+    const auto installed = m_packages[PackageKit::Transaction::InfoInstalled];
+    return installed.isEmpty() ? QString() : installed.first();
 }
 
 QString PackageKitResource::comment()
@@ -93,7 +94,7 @@ QString PackageKitResource::icon() const
 QString PackageKitResource::license()
 {
     fetchDetails();
-    return m_details.license();
+    return m_details.license().isEmpty() ? i18n("Unknown") : m_details.license();
 }
 
 QList<PackageState> PackageKitResource::addonsInformation()
@@ -130,12 +131,12 @@ QString PackageKitResource::section()
 
 QUrl PackageKitResource::screenshotUrl()
 {
-    return QUrl(MuonDataSources::screenshotsSource().toString() + QStringLiteral("/screenshot/") + packageName());
+    return {};
 }
 
 QUrl PackageKitResource::thumbnailUrl()
 {
-    return QUrl(MuonDataSources::screenshotsSource().toString() + QStringLiteral("/thumbnail/") + packageName());
+    return {};
 }
 
 AbstractResource::State PackageKitResource::state()
@@ -152,11 +153,13 @@ AbstractResource::State PackageKitResource::state()
 
 void PackageKitResource::setPackages(const QMap<PackageKit::Transaction::Info, QStringList> &packages)
 {
-    m_packages = packages;
-    emit stateChanged();
+    if (m_packages != packages) {
+        m_packages = packages;
+        emit stateChanged();
+    }
 }
 
-void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const QString &packageId, const QString &/*summary*/)
+void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const QString &packageId)
 {
     m_packages[info].append(packageId);
     emit stateChanged();
@@ -164,119 +167,7 @@ void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const
 
 QStringList PackageKitResource::categories()
 {
-    /*fetchDetails();
-    QStringList categories;
-    switch (m_group) {
-        case PackageKit::Transaction::GroupUnknown:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupAccessibility:
-            categories << "Accessibility";
-            break;
-        case PackageKit::Transaction::GroupAccessories:
-            categories << "Utility";
-            break;
-        case PackageKit::Transaction::GroupAdminTools:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupCommunication:
-            categories << "Chat";
-            break;
-        case PackageKit::Transaction::GroupDesktopGnome:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupDesktopKde:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupDesktopOther:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupDesktopXfce:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupEducation:
-            categories << "Science";
-            break;
-        case PackageKit::Transaction::GroupFonts:
-            categories << "Fonts";
-            break;
-        case PackageKit::Transaction::GroupGames:
-            categories << "Games";
-            break;
-        case PackageKit::Transaction::GroupGraphics:
-            categories << "Graphics";
-            break;
-        case PackageKit::Transaction::GroupInternet:
-            categories << "Internet";
-            break;
-        case PackageKit::Transaction::GroupLegacy:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupLocalization:
-            categories << "Localization";
-            break;
-        case PackageKit::Transaction::GroupMaps:
-            categories << "Geography";
-            break;
-        case PackageKit::Transaction::GroupMultimedia:
-            categories << "Multimedia";
-            break;
-        case PackageKit::Transaction::GroupNetwork:
-            categories << "Network";
-            break;
-        case PackageKit::Transaction::GroupOffice:
-            categories << "Office";
-            break;
-        case PackageKit::Transaction::GroupOther:
-            categories << "Unknown";
-            break;
-        case PackageKit::Transaction::GroupPowerManagement:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupProgramming:
-            categories << "Development";
-            break;
-        case PackageKit::Transaction::GroupPublishing:
-            categories << "Publishing";
-            break;
-        case PackageKit::Transaction::GroupRepos:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupSecurity:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupServers:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupSystem:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupVirtualization:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupScience:
-            categories << "Science";
-            break;
-        case PackageKit::Transaction::GroupDocumentation:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupElectronics:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupCollections:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupVendor:
-            categories << "System";
-            break;
-        case PackageKit::Transaction::GroupNewest:
-            categories << "System";
-            break;
-    };
-    return categories;*/
-    return QStringList(QStringLiteral("Unknown"));
-    //NOTE: I commented the category fetching code, as it seems to get called even for non-technical items
-    //when selecting a category, and receiving details for all packages takes about 20 mins in my VirtualBox and probably not much less on real systems
+    return { QStringLiteral("Unknown") };
 }
 
 bool PackageKitResource::isTechnical() const
@@ -292,7 +183,12 @@ void PackageKitResource::fetchDetails()
 
     PackageKit::Transaction* t = PackageKit::Daemon::getDetails(availablePackageId());
     connect(t, &PackageKit::Transaction::details, this, &PackageKitResource::setDetails);
-    connect(t, &PackageKit::Transaction::errorCode, this, [](PackageKit::Transaction::Error, const QString& msg){ qWarning() << "error fetching details" << msg; });
+    connect(t, &PackageKit::Transaction::errorCode, this, &PackageKitResource::failedFetchingDetails);
+}
+
+void PackageKitResource::failedFetchingDetails(PackageKit::Transaction::Error, const QString& msg)
+{
+    qWarning() << "error fetching details" << msg;
 }
 
 void PackageKitResource::setDetails(const PackageKit::Details & details)
@@ -301,10 +197,13 @@ void PackageKitResource::setDetails(const PackageKit::Details & details)
     if (!ourDetails)
         return;
 
-    m_details = details;
-    emit stateChanged();
+    if (m_details != details) {
+        m_details = details;
+        emit stateChanged();
 
-    backend()->allDataChanged();
+        if (!backend()->isFetching())
+            backend()->resourcesChanged(this, {"size", "homepage", "license"});
+    }
 }
 
 void PackageKitResource::fetchChangelog()
